@@ -16,8 +16,12 @@
 #include "date.h"
 #include "fileutils.h"
 #include "iochannel.h"
+#include "keyfile.h"
 #include "markup.h"
 #include "module.h"
+#include "optioncontext.h"
+#include "optionentry.h"
+#include "optiongroup.h"
 #include "shell.h"
 #include "spawn.h"
 #include "thread.h"
@@ -34,7 +38,9 @@ extern "C"
 GQuark g_convert_error_quark(void);
 GQuark g_file_error_quark(void);
 GQuark g_io_channel_error_quark(void);
+GQuark g_key_file_error_quark(void);
 GQuark g_markup_error_quark(void);
+GQuark g_option_error_quark(void);
 GQuark g_shell_error_quark(void);
 GQuark g_spawn_error_quark(void);
 GQuark g_thread_error_quark(void);
@@ -52,7 +58,9 @@ void wrap_init()
   Glib::Error::register_domain(g_convert_error_quark(), &Glib::ConvertError::throw_func);
   Glib::Error::register_domain(g_file_error_quark(), &Glib::FileError::throw_func);
   Glib::Error::register_domain(g_io_channel_error_quark(), &Glib::IOChannelError::throw_func);
+  Glib::Error::register_domain(g_key_file_error_quark(), &Glib::KeyFileError::throw_func);
   Glib::Error::register_domain(g_markup_error_quark(), &Glib::MarkupError::throw_func);
+  Glib::Error::register_domain(g_option_error_quark(), &Glib::OptionError::throw_func);
   Glib::Error::register_domain(g_shell_error_quark(), &Glib::ShellError::throw_func);
   Glib::Error::register_domain(g_spawn_error_quark(), &Glib::SpawnError::throw_func);
   Glib::Error::register_domain(g_thread_error_quark(), &Glib::ThreadError::throw_func);
